You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@tuscany.apache.org by js...@apache.org on 2006/10/06 07:07:33 UTC

svn commit: r453499 [1/2] - in /incubator/tuscany/cpp/sca: runtime/core/src/tuscany/sca/core/ runtime/core/src/tuscany/sca/model/ samples/BigBank/ samples/BigBank/bigbank.account/ samples/BigBank/bigbank.accountmanagement/ samples/Calculator/ samples/C...

Author: jsdelfino
Date: Thu Oct  5 22:07:31 2006
New Revision: 453499

URL: http://svn.apache.org/viewvc?view=rev&rev=453499
Log:
Removed the requirement for configuration/ and packages/ sub-folders. Composites directly under TUSCANY_SCACPP_SYSTEM_ROOT (top level composites) get included in the SCA system composite (with the same effect as an SCA include), and components that they declare are instanciated in the SCA system. Other composites under that directory tree are available as implementations of components. This change also simplifies the ModelLoader by reusing the same code to load the top-level system composites and the other ones, and the ModelLoader is now able to load nested composites correctly. Finally, as an alternative to TUSCANY_SCACPP_SYSTEM_ROOT, you can now declare a list of directories to scan for top-level composites in TUSCANY_SCACPP_ROOT and a list of directories to scan for implementation composites in TUSCANY_SCACPP_PATH. I adjusted the samples and their build scripts to follow the new simplified folder structure.

Added:
    incubator/tuscany/cpp/sca/samples/BigBank/bigbank.accountmanagement.composite   (with props)
    incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator.solution.composite   (with props)
    incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.solution.composite   (with props)
    incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.accountmanagement.composite   (with props)
    incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.solution.composite   (with props)
    incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.demo.solution.composite   (with props)
    incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.manufacturerA.solution.composite   (with props)
    incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.manufacturerB.solution.composite   (with props)
    incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.manufacturerC.solution.composite   (with props)
    incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.retailer.solution.composite   (with props)
Removed:
    incubator/tuscany/cpp/sca/samples/BigBank/bigbank.accountmanagement/
    incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator.solution/
    incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.solution/
    incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.solution/
    incubator/tuscany/cpp/sca/samples/SupplyChain/supplychain.solution/
Modified:
    incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/SCARuntime.cpp
    incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/SCARuntime.h
    incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/TuscanyRuntime.cpp
    incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/TuscanyRuntime.h
    incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/ModelLoader.cpp
    incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/ModelLoader.h
    incubator/tuscany/cpp/sca/samples/BigBank/Makefile.am
    incubator/tuscany/cpp/sca/samples/BigBank/bigbank.account/Makefile.am
    incubator/tuscany/cpp/sca/samples/Calculator/Makefile.am
    incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator.client/CalculatorClient.cpp
    incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator/Makefile.am
    incubator/tuscany/cpp/sca/samples/PythonCalculator/Makefile.am
    incubator/tuscany/cpp/sca/samples/PythonCalculator/deploy.cmd
    incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/Makefile.am
    incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/runclient.bat
    incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/runclient.sh
    incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/Makefile.am
    incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/runwsclient.bat
    incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/runwsclient.sh
    incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator/Makefile.am
    incubator/tuscany/cpp/sca/samples/RubyBank/Makefile.am
    incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.account/Makefile.am
    incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/Makefile.am
    incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/runclient.bat
    incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/runclient.sh
    incubator/tuscany/cpp/sca/samples/RubyBank/deploy.cmd
    incubator/tuscany/cpp/sca/samples/RubyCalculator/Makefile.am
    incubator/tuscany/cpp/sca/samples/RubyCalculator/deploy.cmd
    incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/Makefile.am
    incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/runclient.bat
    incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/runclient.sh
    incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.wsclient/Makefile.am
    incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.wsclient/runwsclient.bat
    incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.wsclient/runwsclient.sh
    incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator/Makefile.am

Modified: incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/SCARuntime.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/SCARuntime.cpp?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/SCARuntime.h (original)
+++ incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/SCARuntime.h Thu Oct  5 22:07:31 2006
@@ -79,12 +79,18 @@
 
             /**
              * Set the system root
-             * @param root The path to the deployed system.
+             * @param root The path to the system configuration.
              */
             static void setSystemRoot(const string& root);
 
             /**
-             * Set the default CompositeComponent for the system
+             * Set the search path for composites.
+             * @param path The search path for composites.
+             */
+            static void setSystemPath(const string& path);
+
+            /**
+             * Set the default Component for the system
              * @param componentName The name of the default component.
              */
             static void setDefaultComponentName(const string& componentName);
@@ -196,9 +202,14 @@
             string SCARoot;
  
             /**
-             * The path to the system root
+             * The path to the system configuration
              */
             static string systemRoot;
+
+            /**
+             * The search path for composites.
+             */
+            static string systemPath;
 
             /**
              * The default CompositeComponent.

Modified: incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/TuscanyRuntime.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/TuscanyRuntime.cpp?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/TuscanyRuntime.cpp (original)
+++ incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/TuscanyRuntime.cpp Thu Oct  5 22:07:31 2006
@@ -31,7 +31,7 @@
     {
             
         // ==========================================================
-        // Set the default CompositeComponent name
+        // Set the system configuration root path
         // ==========================================================
         void TuscanyRuntime::setSystemRoot(const string& root)
         {
@@ -42,6 +42,17 @@
         }
 
         // ==========================================================
+        // Set the search path for composites
+        // ==========================================================
+        void TuscanyRuntime::setSystemPath(const string& path)
+        {
+            LOGENTRY(1, "TuscanyRuntime::setSystemPath");
+            systemPath = path;
+            LOGINFO_1(3, "TuscanyRuntime::setSystemPath - set to %s", path.c_str());
+            LOGEXIT(1, "TuscanyRuntime::setSystemPath");
+        }
+
+        // ==========================================================
         // Set the default component name
         // ==========================================================
         void TuscanyRuntime::setDefaultComponentName(const string& componentName)
@@ -55,10 +66,11 @@
         // ===================================================================
         // Constructor for the TuscanyRuntime class. 
         // ===================================================================
-        TuscanyRuntime::TuscanyRuntime(const string& componentName, const string& root)
+        TuscanyRuntime::TuscanyRuntime(const string& componentName, const string& root, const string& path)
         { 
             LOGENTRY(1, "TuscanyRuntime::constructor");
             setSystemRoot(root);
+            setSystemPath(path);
             setDefaultComponentName(componentName);           
             LOGEXIT(1, "TuscanyRuntime::constructor");
         }
@@ -79,6 +91,7 @@
         { 
             LOGENTRY(1, "TuscanyRuntime::start");
             SCARuntime::setSystemRoot(systemRoot);
+            SCARuntime::setSystemPath(systemPath);
             SCARuntime::setDefaultComponentName(defaultComponentName);
             SCARuntime::getInstance();
             LOGEXIT(1, "TuscanyRuntime::start");

Modified: incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/TuscanyRuntime.h
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/TuscanyRuntime.h?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/TuscanyRuntime.h (original)
+++ incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/TuscanyRuntime.h Thu Oct  5 22:07:31 2006
@@ -40,7 +40,8 @@
             /**
             * Default constructor
             */
-            TuscanyRuntime(const string& defaultComponentName = "", const string& root = "");            
+            TuscanyRuntime(const string& defaultComponentName = "",
+                const string& root = "", const string& path = "");            
             
             /**
             * Destructor
@@ -49,12 +50,18 @@
             
             
             /**
-            * Set the system root
-            * @param root The path to the deployed system.
+            * Set the system root configuration path
+            * @param root The path to the system configuration.
             */
             void setSystemRoot(const string& root);
             
             /**
+            * Set the system composite search path
+            * @param root The search path for composites.
+            */
+            void setSystemPath(const string& path);
+            
+            /**
             * Set the default component for the system
             * @param componentName The name of the default component.
             */
@@ -73,6 +80,7 @@
             
         private:
             string systemRoot;
+            string systemPath;
             string defaultComponentName;
         };
 

Modified: incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/ModelLoader.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/ModelLoader.cpp?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/ModelLoader.cpp (original)
+++ incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/ModelLoader.cpp Thu Oct  5 22:07:31 2006
@@ -41,6 +41,12 @@
 using namespace commonj::sdo;
 
 
+#if defined(WIN32)  || defined (_WINDOWS)
+#define PATH_SEPARATOR ";"
+#else
+#define PATH_SEPARATOR ":"
+#endif 
+
 namespace tuscany
 {
     namespace sca
@@ -72,224 +78,168 @@
             // This class has the responsibility for translating from
             // the SCDL files to the SCA runtime's in memory model.
             // =========================================================
-            void ModelLoader::load(const string& systemRoot)
+            void ModelLoader::load(const string& systemRoot, const string& systemPath)
             {
                 LOGENTRY(1, "ModelLoader::load");
                 LOGINFO_1(2,"system root: %s", systemRoot.c_str());
+                LOGINFO_1(2,"system path: %s", systemPath.c_str());
                 
-                // The configuration root path will point to a directory structure.
-                
-                // Implementation packages can occur anywhere under the packages directory
-                loadPackages(systemRoot+"/packages");
+                // Load composite implementations
+                // Composite implementations can occur anywhere on the given search path
+                if (systemPath != "")
+                {
+                    loadComposites(systemRoot + PATH_SEPARATOR + systemPath);
+                }
+                else
+                {
+                    loadComposites(systemRoot);
+                }
                 
-                // The composite files representing the configuration of the system can be located
-                // anywhere under the configuration directory.
-                loadConfiguration(systemRoot+"/configuration");
+                // Load system composites
+                // Composites on the the system root path get included
+                // in the System composite
+                loadSystem(systemRoot);
                 
+                // Resolve the wires in the system composite
                 system->resolveWires();
                 
                 LOGEXIT(1, "ModelLoader::load");
             }
             
             // ========================================================================
-            // loadConfiguration:
-            // Load all the composite files from any directory below the configuration root.
-            // Translate the configuration information to the runtime information
+            // loadSystem:
+            // Load all the composite files on the system root path
+            // Translate the composite information to composite model objects
             // ========================================================================
-            void ModelLoader::loadConfiguration(const string& configurationRoot)
+            void ModelLoader::loadSystem(const string& systemRoot)
             {
-                // Get all the composite files in the configuration directory
-                LOGENTRY(1, "ModelLoader::loadConfiguration");
-                Files files(configurationRoot, "*.composite", true);
-                for (unsigned int i=0; i < files.size(); i++)
-                {
-                    Composite* include = loadConfigurationCompositeFile(files[i]);
-                    
-                    // Include each composite in the system composite
-                    system->addInclude(include);
+                // Get all the composite files on the system root path
+                // These composites are included in the system composite
+                LOGENTRY(1, "ModelLoader::loadSystem");
+                for (string path = systemRoot; path != ""; )
+                {
+                    string dir;
+                    Utils::tokeniseString(PATH_SEPARATOR, path, dir, path);
+                    if (dir != "")
+                    {
+                        LOGINFO_1(2, "system root directory: %s", dir.c_str());
+                        Files files(dir, "*.composite", false);
+                        for (unsigned int i=0; i < files.size(); i++)
+                        {
+                            string fileName = files[i].getDirectory() + "/" + files[i].getFileName();
+                            Composite* composite = compositeFiles[fileName];
+                            if (composite)
+                            {
+                                // Include the composite in the system composite
+                                system->addInclude(composite);
+                            }
+                            else
+                            {
+                                // We already got an error or warning indicating why the file
+                                // didn't turn into a composite
+                            }
+                        }
+                    }
                 }
-                LOGEXIT(1, "ModelLoader::loadConfiguration");
+                LOGEXIT(1, "ModelLoader::loadSystem");
             }
             
-            
             // =====================================================================
-            // loadConfigurationFile:
-            // This method is called for each composite file found in the configuration
-            // folder structure
+            // loadComposites:
+            // Load all the composites from any directory under the composite search path
+            // Translate the composite information to composite model objects
             // =====================================================================
-            Composite* ModelLoader::loadConfigurationCompositeFile(const File& file)
-            {
-                LOGENTRY(1, "ModelLoader::loadConfigurationCompositeFile");
-                LOGINFO_1(2, "configuration filename: %s", file.getFileName().c_str());
-                
-                Composite* include;
-                try
-                {
-                    string filename = file.getDirectory() + "/" + file.getFileName();
-                    XMLDocumentPtr configurationFile = getXMLHelper()->loadFile(filename.c_str());
-                    if (configurationFile->getRootDataObject() == 0)
-                    {
-                        LOGERROR_1(0, "ModelLoader::loadConfigurationCompositeFile: Unable to load file: %s", filename.c_str());
-                    }
-                    else
-                    {    
-                        //Utils::printDO(configurationFile->getRootDataObject());
-                        include = mapConfigurationComposite(configurationFile->getRootDataObject(), file.getDirectory());        
-                    }
-                } catch (SDORuntimeException ex) 
-                {
-                    LOGERROR_1(0, "ModelLoader::loadConfigurationCompositeFile: Exception caught: %s", ex.getMessageText());
-                }    
-                
-                LOGEXIT(1, "ModelLoader::loadConfigurationCompositeFile");
-                return include;
-            }
-            
-            // ===============
-            // mapConfiguration:
-            // ===============
-            Composite* ModelLoader::mapConfigurationComposite(DataObjectPtr root, string compositeRootDir)
+            void ModelLoader::loadComposites(const string& searchPath)
             {
-                LOGENTRY(1, "ModelLoader::mapConfigurationComposite");
-                
-                LOGINFO_1(2, "ModelLoader::mapConfigurationComposite: Loaded configuration: %s", root->getCString("name"));
-
-                // Create a composite and include it in the system                
-                Composite* include = new Composite(root->getCString("name"), compositeRootDir); 
-                
-                DataObjectList& componentDOs = root->getList("component");
-                LOGINFO_1(2, "ModelLoader::mapConfigurationComposite: number of composite components: %d", componentDOs.size());
-                
-                // Iterate over components
-                for (int i=0; i<componentDOs.size(); i++)
-                {
-                    // Get the composite component implementation
-                    DataObjectPtr impl = componentDOs[i]->getDataObject("implementation");
-                    if (!impl)
-                    {
-                        string message = "No implementation for component: ";
-                        message = message + componentDOs[i]->getCString("name");
-                        throw SystemConfigurationException(message.c_str());
-                    }
-                    
-                    // Determine the implementation type
-                    string implementationType = impl->getType().getName();
-                    if (implementationType == "SCAImplementation")
-                    {
-                        // Add each composite component to the include
-                        
-                        Composite* composite = packages[impl->getCString("name")];
-                        if (!composite)
-                        {
-                            string message = "Composite not found: ";
-                            message = message + impl->getCString("name");
-                            throw SystemConfigurationException(message.c_str());
-                        }
-                        else
+                // Get all the composite files on the composite search path
+                LOGENTRY(1, "ModelLoader::loadComposites");
+                for (string path = searchPath; path != ""; )
+                {
+                    string dir;
+                    Utils::tokeniseString(PATH_SEPARATOR, path, dir, path);
+                    if (dir != "")
+                    {
+                        LOGINFO_1(2, "composite path directory: %s", dir.c_str());
+                        Files files(dir, "*.composite", true);
+                        for (unsigned int i=0; i < files.size(); i++)
                         {
-                            Component* component = new Component(include, componentDOs[i]->getCString("name"), composite);
-                            include->addComponent(component);
+                            loadCompositeFile(files[i]);
                         }
                     }
-                    else
-                    {
-                        string message = "Atomic component implementation not yet supported in a system include: ";
-                        message = message + componentDOs[i]->getCString("name");
-                        throw SystemConfigurationException(message.c_str());
-                    }
                 }
                 
-                //TODO Add composite services and references
-                
-                LOGEXIT(1, "ModelLoader::mapConfigurationComposite");
-                return include;
-            }
-            
-            
-            // =====================================================================
-            // loadPackages:
-            // Load all the composites from any directory below the packages root.
-            // Translate the composite information to the runtime information
-            // =====================================================================
-            void ModelLoader::loadPackages(const string& installRoot)
-            {
-                // Get all the composite files
-                LOGENTRY(1, "ModelLoader::loadPackages");
-                Files files(installRoot, "*.composite", true);
-                for (unsigned int i=0; i < files.size(); i++)
+                // Complete the mapping of the composites
+                for (COMPOSITE_DATAOBJECTS::iterator iter = compositeDataObjects.begin();
+                iter != compositeDataObjects.end();
+                iter++)
                 {
-                    loadPackageCompositeFile(files[i]);
+                    mapCompositePass2(iter->first, iter->second);
                 }
-                LOGEXIT(1, "ModelLoader::loadPackages");
+                
+                LOGEXIT(1, "ModelLoader::loadComposites");
             }
             
-            
             // ====================================================================
-            // loadPackageCompositeFile:
-            // This method is called for each .composite file found in the packages
-            // folder structure
-            // The location of this composite file will indicate the root of a composite
+            // loadCompositeFile:
+            // This method is called for each .composite file found under the composite search
+            // path. The location of this composite file will indicate the root of a composite.
             // ====================================================================
-            Composite* ModelLoader::loadPackageCompositeFile(const File& file)
+            Composite* ModelLoader::loadCompositeFile(const File& file)
             {
-                LOGENTRY(1, "ModelLoader::loadPackageCompositeFile");
+                LOGENTRY(1, "ModelLoader::loadCompositeFile");
                 LOGINFO_1(2, "composite filename: %s", file.getFileName().c_str());
 
                 Composite* composite = NULL;                
                 try 
                 {
                     string fileName = file.getDirectory() + "/" + file.getFileName();
-                    XMLDocumentPtr compositeFile = getXMLHelper()->loadFile(fileName.c_str());
-                    if (compositeFile->getRootDataObject() == NULL)
-                    {
-                        LOGERROR_1(0, "ModelLoader::loadPackageCompositeFile: Unable to load file: %s", fileName.c_str());
-                    }
-                    else
+                    if (compositeFiles[fileName] == NULL)
                     {
-                        // Map the SCDL 
-                        composite = mapPackageComposite(compositeFile->getRootDataObject(), file.getDirectory());                        
-
-                        // Load the xsd types and wsdl files in the composite
-                        loadTypeMetadata(composite, file.getDirectory());
+                        XMLDocumentPtr compositeFile = getXMLHelper()->loadFile(fileName.c_str());
+                        if (compositeFile->getRootDataObject() == NULL)
+                        {
+                            LOGERROR_1(0, "ModelLoader::loadCompositeFile: Unable to load file: %s", fileName.c_str());
+                        }
+                        else
+                        {
+                            // Map the SCDL 
+                            composite = mapCompositePass1(file, compositeFile->getRootDataObject());                        
+    
+                            // Load the xsd types and wsdl files in the composite
+                            loadTypeMetadata(file.getDirectory(), composite);
+                        }
                     }
                     
                 } catch (SDORuntimeException ex) 
                 {
-                    LOGERROR_1(0, "ModelLoader::loadPackageCompositeFile: Exception caught: %s", ex.getMessageText());
+                    LOGERROR_1(0, "ModelLoader::loadCompositeFile: Exception caught: %s", ex.getMessageText());
                 }    
                 
-                LOGEXIT(1, "ModelLoader::loadPackageCompositeFile");
+                LOGEXIT(1, "ModelLoader::loadCompositeFile");
                 return composite;
             }
             
             // ===========
-            // mapPackageComposite
+            // mapCompositePass1
             // ===========
-            Composite* ModelLoader::mapPackageComposite(DataObjectPtr root, string compositeRootDir)
+            Composite* ModelLoader::mapCompositePass1(const File& file, DataObjectPtr root)
             {
-                LOGENTRY(1, "ModelLoader::mapPackageComposite");
+                LOGENTRY(1, "ModelLoader::mapCompositePass1");
                 
-                string compositeName = root->getCString("name");
-                LOGINFO_2(2, "ModelLoader::mapPackageComposite: Loading composite: %s, root Dir: %s", compositeName.c_str(), compositeRootDir.c_str());
+                const string& compositeRootDir = file.getDirectory();
+                const string compositeName = root->getCString("name");
+                LOGINFO_2(2, "ModelLoader::mapCompositePass1: Loading composite: %s, root Dir: %s", compositeName.c_str(), compositeRootDir.c_str());
                 
                 Composite* composite = new Composite(compositeName, compositeRootDir);
-                packages[compositeName] = composite; 
+                compositeModels[compositeName] = composite; 
+                compositeDataObjects[compositeName] = root;
+                compositeFiles[file.getDirectory() + "/" + file.getFileName()] = composite;
                 
-                // ----------------------------
-                // Add components to the composite
-                // ----------------------------
-                DataObjectList& componentList = root->getList("component");
-                int i;
-                for (i=0; i < componentList.size(); i++)
-                {
-                    addComponent(composite, componentList[i]);                        
-                }
-
                 // ------------
                 // Composite services
                 // ------------
                 DataObjectList& compositeServiceList = root->getList("service");
-                for (i=0; i < compositeServiceList.size(); i++)
+                for (int i = 0; i < compositeServiceList.size(); i++)
                 {
                     addCompositeService(composite, compositeServiceList[i]);                        
                 }
@@ -298,7 +248,7 @@
                 // Composite references
                 // -----------------
                 DataObjectList& compositeReferenceList = root->getList("reference");
-                for (i=0; i < compositeReferenceList.size(); i++)
+                for (int i = 0; i < compositeReferenceList.size(); i++)
                 {
                     addCompositeReference(composite, compositeReferenceList[i]);
                 }
@@ -307,16 +257,42 @@
                 // Wires
                 // -----
                 DataObjectList& wireList = root->getList("wire");
-                for (int l=0; l < wireList.size(); l++)
+                for (int l = 0; l < wireList.size(); l++)
                 {
                     string source = wireList[l]->getCString("source");
                     string target = wireList[l]->getCString("target");
                     composite->addWire(source, target);
                 }
                 
+                LOGEXIT(1, "ModelLoader::mapCompositePass1");
+                return composite;
+            }
+
+            // ===========
+            // mapCompositePass2
+            // ===========
+            Composite* ModelLoader::mapCompositePass2(const string& compositeName, DataObjectPtr root)
+            {
+                LOGENTRY(1, "ModelLoader::mapCompositePass2");
+                
+                LOGINFO_1(2, "ModelLoader::mapCompositePass2: Loading composite: %s", compositeName.c_str());
+                
+                Composite* composite = compositeModels[compositeName]; 
+                
+                // ----------------------------
+                // Add components to the composite
+                // ----------------------------
+                DataObjectList& componentList = root->getList("component");
+                int i;
+                for (i=0; i < componentList.size(); i++)
+                {
+                    addComponent(composite, componentList[i]);                        
+                }
+
+                // Resolve all the wires inside the composite
                 composite->resolveWires();
                                 
-                LOGEXIT(1, "ModelLoader::mapPackageComposite");
+                LOGEXIT(1, "ModelLoader::mapCompositePass2");
                 return composite;
             }
 
@@ -341,61 +317,76 @@
                 string componentTypeName;
                 string componentTypePath;
 
-                string implementationType = impl->getType().getName();
                 string implTypeQname = impl->getType().getURI();
                 implTypeQname += "#";
                 implTypeQname += impl->getType().getName();
-
-                // Locate extension that handles this implementation type
-                ImplementationExtension* implExtension = runtime->getImplementationExtension(implTypeQname);
-                if (implExtension)
-                {
-                    componentType = implExtension->getImplementation(impl);
-                    
-                    // -----------------------
-                    // Load the .componentType
-                    // -----------------------
-                    string typeFileName = composite->getRoot() + "/" + componentType->getName() + ".componentType";
-
-                    // Check that the component type file exists
-                    //TODO We need a better and portable way to do this
-                    string dirName;
-                    string fileName;                    
-                    Utils::rTokeniseString("/", typeFileName, dirName, fileName);
-                    Files files(dirName, fileName, false);
-                    if (files.size() !=0)
+                
+                if (implTypeQname == "http://www.osoa.org/xmlns/sca/1.0#SCAImplementation")
+                {
+                    // Handle a composite implementation 
+                    Composite* composite = compositeModels[impl->getCString("name")];
+                    if (!composite)
                     {
-                        try 
-                        {
-                            XMLDocumentPtr componentTypeFile = getXMLHelper()->loadFile(typeFileName.c_str());
-                            if (!componentTypeFile || componentTypeFile->getRootDataObject() == 0)
-                            {
-                                // Component type files are optional
-                                LOGINFO_1(0, "ModelLoader::addComponent: Unable to load file: %s", typeFileName.c_str());
-                            }
-                            else
-                            {                                            
-                                //Utils::printDO(componentTypeFile->getRootDataObject());
-                                //commonj::sdo::SDOUtils::printDataObject(componentTypeFile->getRootDataObject());
-                                addServiceTypes(composite, componentType, componentTypeFile->getRootDataObject());
-                                addReferenceTypes(composite, componentType, componentTypeFile->getRootDataObject());
-                                addPropertyTypes(componentType, componentTypeFile->getRootDataObject());
-                            }
-                        } catch (SDORuntimeException& ex) 
-                        {
-                            LOGERROR_2(0, "ModelLoader::addComponent (%s): Exception caught: %s",
-                                typeFileName.c_str(), ex.getMessageText());
-                            throw SystemConfigurationException(ex.getMessageText());
-                        }
-                    }    
+                        string message = "Composite not found: ";
+                        message = message + impl->getCString("name");
+                        throw SystemConfigurationException(message.c_str());
+                    }
+                    componentType = composite;
                 }
                 else
                 {
-                    LOGERROR_1(0, "ModelLoader::addComponent: Unsupported implementation type: %s", implTypeQname.c_str());
-
-                    string message = "Implementation type not supported: ";
-                    message = message + implTypeQname;
-                    throw SystemConfigurationException(message.c_str());
+    
+                    // Locate extension that handles this implementation type
+                    ImplementationExtension* implExtension = runtime->getImplementationExtension(implTypeQname);
+                    if (implExtension)
+                    {
+                        componentType = implExtension->getImplementation(impl);
+                        
+                        // -----------------------
+                        // Load the .componentType
+                        // -----------------------
+                        string typeFileName = composite->getRoot() + "/" + componentType->getName() + ".componentType";
+    
+                        // Check that the component type file exists
+                        //TODO We need a better and portable way to do this
+                        string dirName;
+                        string fileName;                    
+                        Utils::rTokeniseString("/", typeFileName, dirName, fileName);
+                        Files files(dirName, fileName, false);
+                        if (files.size() !=0)
+                        {
+                            try 
+                            {
+                                XMLDocumentPtr componentTypeFile = getXMLHelper()->loadFile(typeFileName.c_str());
+                                if (!componentTypeFile || componentTypeFile->getRootDataObject() == 0)
+                                {
+                                    // Component type files are optional
+                                    LOGINFO_1(0, "ModelLoader::addComponent: Unable to load file: %s", typeFileName.c_str());
+                                }
+                                else
+                                {                                            
+                                    //Utils::printDO(componentTypeFile->getRootDataObject());
+                                    //commonj::sdo::SDOUtils::printDataObject(componentTypeFile->getRootDataObject());
+                                    addServiceTypes(composite, componentType, componentTypeFile->getRootDataObject());
+                                    addReferenceTypes(composite, componentType, componentTypeFile->getRootDataObject());
+                                    addPropertyTypes(componentType, componentTypeFile->getRootDataObject());
+                                }
+                            } catch (SDORuntimeException& ex) 
+                            {
+                                LOGERROR_2(0, "ModelLoader::addComponent (%s): Exception caught: %s",
+                                    typeFileName.c_str(), ex.getMessageText());
+                                throw SystemConfigurationException(ex.getMessageText());
+                            }
+                        }    
+                    }
+                    else
+                    {
+                        LOGERROR_1(0, "ModelLoader::addComponent: Unsupported implementation type: %s", implTypeQname.c_str());
+    
+                        string message = "Implementation type not supported: ";
+                        message = message + implTypeQname;
+                        throw SystemConfigurationException(message.c_str());
+                    }
                 }
                 
                 // First check that references exist, some component types
@@ -713,7 +704,7 @@
             /// Use the Tuscany.config file in the composite root directory to
             /// determine which xsds and wsdls to load into a dataFactory.
             ///
-            void ModelLoader::loadTypeMetadata(Composite* composite, const string &compositeRootDir)
+            void ModelLoader::loadTypeMetadata(const string &compositeRootDir, Composite* composite)
             {
                 LOGENTRY(1, "ModelLoader::loadTypeMetadata");
 
@@ -777,16 +768,16 @@
                     for (unsigned int i=0; i < xsdFiles.size(); i++)
                     {
                         // Load a xsd file -> set the types in the compositeComponents data factory file
-                        string xsdName = compositeRootDir + "/" + xsdFiles[i].getFileName();
+                        string xsdName = xsdFiles[i].getDirectory() + "/" + xsdFiles[i].getFileName();
                         loadXMLSchema(composite, xsdName.c_str());
                         
                     }                    
 
                     Files wsdlFiles(compositeRootDir, "*.wsdl", true);
-                    for (unsigned int wi=0; wi < wsdlFiles.size(); wi++)
+                    for (unsigned int i=0; i < wsdlFiles.size(); i++)
                     {
                         // Load a wsdl file -> get the types, then the contents of the wsdl
-                        string wsdlName = compositeRootDir + "/" + wsdlFiles[wi].getFileName();
+                        string wsdlName = wsdlFiles[i].getDirectory() + "/" + wsdlFiles[i].getFileName();
                         loadXMLSchema(composite, wsdlName.c_str());
                         
                         // Load the contents of the wsdl files

Modified: incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/ModelLoader.h
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/ModelLoader.h?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/ModelLoader.h (original)
+++ incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/model/ModelLoader.h Thu Oct  5 22:07:31 2006
@@ -66,27 +66,18 @@
                 
                 /**
                  * Load the model from the configuration information.
-                 * @param configurationRoot The location of the deployed SCA
-                 * packages and configuration.
+                 * @param systemRoot The location of the system configuration
+                 * @param systemPath The search path for composites
                  */
-                void load(const string& systemRoot);
+                void load(const string& systemRoot, const string& systemPath);
                 
             private:
-                void loadComposite(const char *compositeRoot);
+                void loadSystem(const string& systemRoot);
                 
-                commonj::sdo::XMLHelperPtr myXMLHelper;    // Used to load scdl files
-                commonj::sdo::XSDHelperPtr myXSDHelper; // Used to load xsds
-                
-                const commonj::sdo::XSDHelperPtr getXSDHelper(void);
-                const commonj::sdo::XMLHelperPtr getXMLHelper(void);
-                
-                void loadConfiguration(const string& configurationRoot);
-                Composite* loadConfigurationCompositeFile(const File& file);
-                Composite* mapConfigurationComposite(DataObjectPtr rootDO, const string compositeRootDir);
-                
-                void loadPackages(const string& installRoot);
-                Composite* loadPackageCompositeFile(const File& file);
-                Composite* mapPackageComposite(DataObjectPtr rootDO, const string compositeRootDir);
+                void loadComposites(const string& searchPath);
+                Composite* loadCompositeFile(const File& file);
+                Composite* mapCompositePass1(const File& file, DataObjectPtr rootDO);
+                Composite* mapCompositePass2(const string& compositeName, DataObjectPtr rootDO);
 
                 void addComponent(Composite* composite, DataObjectPtr componentDO);
                 void addCompositeService(Composite* composite, DataObjectPtr compositeServiceDO);
@@ -96,7 +87,7 @@
                 void addReferenceTypes(Composite* composite, ComponentType* componentType, DataObjectPtr componentTypeDO);
                 void addPropertyTypes(ComponentType* componentType, DataObjectPtr componentTypeDO);
 
-                void loadTypeMetadata(Composite* composite, const string &compositeRootDir);
+                void loadTypeMetadata(const string &compositeRootDir, Composite* composite);
                 
                 void loadXMLSchema(Composite* composite, const char *fileName);
                 void loadWSDLDefinition(Composite* composite, const char *fileName);
@@ -106,18 +97,28 @@
 
                 SCARuntime* runtime;
 
+                commonj::sdo::XMLHelperPtr myXMLHelper;    // Used to load scdl files
+                commonj::sdo::XSDHelperPtr myXSDHelper; // Used to load xsds
+                
+                const commonj::sdo::XSDHelperPtr getXSDHelper(void);
+                const commonj::sdo::XMLHelperPtr getXMLHelper(void);
+                
                 /**
                  * The composite describing the composition of the system
-                 * All the composites under the configuration root directory are
-                 * included in the system composite.
                  */
                 Composite* system;
             
                 /**
-                 * Map of all the package composites installed on the system.
+                 * Maps of all the composites installed on the system.
                  */
-                typedef map<string, Composite*> PACKAGES;
-                PACKAGES packages;
+                typedef map<string, Composite*> COMPOSITE_MODELS;
+                COMPOSITE_MODELS compositeModels;
+                
+                typedef map<string, DataObjectPtr> COMPOSITE_DATAOBJECTS;
+                COMPOSITE_DATAOBJECTS compositeDataObjects;
+
+                typedef map<string, Composite*> COMPOSITE_FILES;
+                COMPOSITE_FILES compositeFiles;
 
             };
         } // End namespace model

Modified: incubator/tuscany/cpp/sca/samples/BigBank/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/BigBank/Makefile.am?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/BigBank/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/BigBank/Makefile.am Thu Oct  5 22:07:31 2006
@@ -1,4 +1,4 @@
-deploydir=$(prefix)/samples/BigBank/deploy/configuration/bigbank.accountmanagement
+deploydir=$(prefix)/samples/BigBank/deploy
 SUBDIRS = bigbank.account bigbank.client bigbank.wsclient
-EXTRA_DIST = bigbank.accountmanagement README.html
-deploy_DATA = bigbank.accountmanagement/bigbank.accountmanagement.composite
+EXTRA_DIST = *.composite README.html
+deploy_DATA = *.composite

Modified: incubator/tuscany/cpp/sca/samples/BigBank/bigbank.account/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/BigBank/bigbank.account/Makefile.am?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/BigBank/bigbank.account/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/BigBank/bigbank.account/Makefile.am Thu Oct  5 22:07:31 2006
@@ -1,5 +1,5 @@
 deploydir=$(prefix)/samples/BigBank/deploy
-compositedir=$(deploydir)/packages/bigbank.account
+compositedir=$(deploydir)/bigbank.account
 prgbindir=$(deploydir)/bin
 
 BUILT_SOURCES = AccountDataServiceImpl_AccountDataService_Proxy.cpp \

Added: incubator/tuscany/cpp/sca/samples/BigBank/bigbank.accountmanagement.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/BigBank/bigbank.accountmanagement.composite?view=auto&rev=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/BigBank/bigbank.accountmanagement.composite (added)
+++ incubator/tuscany/cpp/sca/samples/BigBank/bigbank.accountmanagement.composite Thu Oct  5 22:07:31 2006
@@ -0,0 +1,30 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--
+   Licensed to the Apache Software Foundation (ASF) under one
+   or more contributor license agreements.  See the NOTICE file
+   distributed with this work for additional information
+   regarding copyright ownership.  The ASF licenses this file
+   to you under the Apache License, Version 2.0 (the
+   "License"); you may not use this file except in compliance
+   with the License.  You may obtain a copy of the License at
+   
+     http://www.apache.org/licenses/LICENSE-2.0
+     
+   Unless required by applicable law or agreed to in writing,
+   software distributed under the License is distributed on an
+   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+   KIND, either express or implied.  See the License for the
+   specific language governing permissions and limitations
+   under the License.
+-->
+
+
+<composite xmlns="http://www.osoa.org/xmlns/sca/1.0"
+	name="bigbank.accountmanagement">
+	
+	<component name="bigbank.AccountManagementComponent">
+		<implementation.composite name="bigbank.account"/>
+	</component>
+
+</composite>
+	
\ No newline at end of file

Propchange: incubator/tuscany/cpp/sca/samples/BigBank/bigbank.accountmanagement.composite
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/tuscany/cpp/sca/samples/BigBank/bigbank.accountmanagement.composite
------------------------------------------------------------------------------
    svn:keywords = Rev Date

Modified: incubator/tuscany/cpp/sca/samples/Calculator/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/Calculator/Makefile.am?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/Calculator/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/Calculator/Makefile.am Thu Oct  5 22:07:31 2006
@@ -1,4 +1,4 @@
-deploydir=$(prefix)/samples/Calculator/deploy/configuration
+deploydir=$(prefix)/samples/Calculator/deploy
 SUBDIRS = sample.calculator sample.calculator.client sample.calculator.wsclient
-EXTRA_DIST = sample.calculator.solution README.html
-deploy_DATA = sample.calculator.solution/sample.calculator.solution.composite
\ No newline at end of file
+EXTRA_DIST = *.composite README.html
+deploy_DATA = *.composite

Modified: incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator.client/CalculatorClient.cpp
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator.client/CalculatorClient.cpp?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator.client/CalculatorClient.cpp (original)
+++ incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator.client/CalculatorClient.cpp Thu Oct  5 22:07:31 2006
@@ -72,14 +72,6 @@
 
     try
     {
-        // Set the default  environment variable: <subsystem>/<Name>
-        string systemRoot = getenv("TUSCANY_SCACPP");
-        if (systemRoot  == "")
-        {
-            cout << "TUSCANY_SCACPP environment variable not set" <<endl;
-            return -1;
-        }
-        
         // Locate a service
 		CompositeContext myContext = CompositeContext::getCurrent();
 		Calculator *calcService = (Calculator*) myContext.locateService("CalculatorComponent/CalculatorService");

Added: incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator.solution.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator.solution.composite?view=auto&rev=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator.solution.composite (added)
+++ incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator.solution.composite Thu Oct  5 22:07:31 2006
@@ -0,0 +1,29 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--
+   Licensed to the Apache Software Foundation (ASF) under one
+   or more contributor license agreements.  See the NOTICE file
+   distributed with this work for additional information
+   regarding copyright ownership.  The ASF licenses this file
+   to you under the Apache License, Version 2.0 (the
+   "License"); you may not use this file except in compliance
+   with the License.  You may obtain a copy of the License at
+   
+     http://www.apache.org/licenses/LICENSE-2.0
+     
+   Unless required by applicable law or agreed to in writing,
+   software distributed under the License is distributed on an
+   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+   KIND, either express or implied.  See the License for the
+   specific language governing permissions and limitations
+   under the License.
+-->
+
+<composite xmlns="http://www.osoa.org/xmlns/sca/1.0"
+	name="sample.calculator.solution">
+	
+        <component name="sample.calculator.CalculatorComponent">
+        	<implementation.composite name="sample.calculator" />
+       	</component>
+
+</composite>
+

Propchange: incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator.solution.composite
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator.solution.composite
------------------------------------------------------------------------------
    svn:keywords = Rev Date

Modified: incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator/Makefile.am?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/Calculator/sample.calculator/Makefile.am Thu Oct  5 22:07:31 2006
@@ -1,5 +1,5 @@
 deploydir=$(prefix)/samples/Calculator/deploy
-compositedir=$(deploydir)/packages/sample.calculator
+compositedir=$(deploydir)/sample.calculator
 prgbindir=$(deploydir)/bin
 
 BUILT_SOURCES = CalculatorImpl_CalculatorService_Proxy.cpp \

Modified: incubator/tuscany/cpp/sca/samples/PythonCalculator/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/PythonCalculator/Makefile.am?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/PythonCalculator/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/PythonCalculator/Makefile.am Thu Oct  5 22:07:31 2006
@@ -1,4 +1,4 @@
-deploydir=$(prefix)/samples/PythonCalculator/deploy/configuration
+deploydir=$(prefix)/samples/PythonCalculator/deploy
 SUBDIRS = sample.calculator sample.calculator.client sample.calculator.wsclient
-EXTRA_DIST = sample.calculator.solution README.html
-deploy_DATA = sample.calculator.solution/sample.calculator.solution.composite
\ No newline at end of file
+EXTRA_DIST = *.composite README.html
+deploy_DATA = *.composite

Modified: incubator/tuscany/cpp/sca/samples/PythonCalculator/deploy.cmd
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/PythonCalculator/deploy.cmd?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/PythonCalculator/deploy.cmd (original)
+++ incubator/tuscany/cpp/sca/samples/PythonCalculator/deploy.cmd Thu Oct  5 22:07:31 2006
@@ -28,24 +28,22 @@
 set destinationPath=%2
 )
 
-if not exist %destinationPath%\packages                   mkdir %destinationPath%\packages 
-if not exist %destinationPath%\packages\sample.calculator mkdir %destinationPath%\packages\sample.calculator
-copy %sourcePath%\sample.calculator\*.componentType %destinationPath%\packages\sample.calculator
-copy %sourcePath%\sample.calculator\*.composite     %destinationPath%\packages\sample.calculator
-copy %sourcePath%\sample.calculator\*.py            %destinationPath%\packages\sample.calculator
-copy %sourcePath%\sample.calculator\Calculator.wsdl %destinationPath%\packages\sample.calculator
+if not exist %destinationPath%                          mkdir %destinationPath%
+if not exist %destinationPath%\sample.calculator mkdir %destinationPath%\sample.calculator
+copy %sourcePath%\sample.calculator\*.componentType %destinationPath%\sample.calculator
+copy %sourcePath%\sample.calculator\*.composite     %destinationPath%\sample.calculator
+copy %sourcePath%\sample.calculator\*.py            %destinationPath%\sample.calculator
+copy %sourcePath%\sample.calculator\Calculator.wsdl %destinationPath%\sample.calculator
 
-if not exist %destinationPath%\packages\sample.calculator.client mkdir %destinationPath%\packages\sample.calculator.client
-copy %sourcePath%\sample.calculator.client\calculator_client.py %destinationPath%\packages\sample.calculator.client
+if not exist %destinationPath%\sample.calculator.client mkdir %destinationPath%\sample.calculator.client
+copy %sourcePath%\sample.calculator.client\calculator_client.py %destinationPath%\sample.calculator.client
 
-if not exist %destinationPath%\packages\sample.calculator.wsclient mkdir %destinationPath%\packages\sample.calculator.wsclient
-copy %sourcePath%\sample.calculator.wsclient\calculator_wsclient.py               %destinationPath%\packages\sample.calculator.wsclient
-copy %sourcePath%\sample.calculator.wsclient\sample.calculator.wsclient.composite %destinationPath%\packages\sample.calculator.wsclient
-copy %sourcePath%\sample.calculator.wsclient\Calculator.wsdl                      %destinationPath%\packages\sample.calculator.wsclient
+if not exist %destinationPath%\sample.calculator.wsclient mkdir %destinationPath%\sample.calculator.wsclient
+copy %sourcePath%\sample.calculator.wsclient\calculator_wsclient.py               %destinationPath%\sample.calculator.wsclient
+copy %sourcePath%\sample.calculator.wsclient\sample.calculator.wsclient.composite %destinationPath%\sample.calculator.wsclient
+copy %sourcePath%\sample.calculator.wsclient\Calculator.wsdl                      %destinationPath%\sample.calculator.wsclient
 
-if not exist %destinationPath%\configuration                            mkdir %destinationPath%\configuration
-if not exist %destinationPath%\configuration\sample.calculator.solution mkdir %destinationPath%\configuration\sample.calculator.solution
-copy %sourcePath%\sample.calculator.solution\*.composite %destinationPath%\configuration\sample.calculator.solution
+copy %sourcePath%\*.composite %destinationPath%
 
 if not exist %destinationPath%\bin mkdir %destinationPath%\bin
 copy %sourcePath%\sample.calculator.client\runclient.bat     %destinationPath%\bin

Modified: incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/Makefile.am?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/Makefile.am Thu Oct  5 22:07:31 2006
@@ -1,5 +1,5 @@
 deploydir=$(prefix)/samples/PythonCalculator/deploy
-clientdir=$(deploydir)/packages/sample.calculator.client
+clientdir=$(deploydir)/sample.calculator.client
 prgbindir=$(deploydir)/bin
 
 client_DATA = *.py

Modified: incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/runclient.bat
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/runclient.bat?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/runclient.bat (original)
+++ incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/runclient.bat Thu Oct  5 22:07:31 2006
@@ -43,7 +43,7 @@
 set PATH=%TUSCANY_SCACPP%\bin;%TUSCANY_SCACPP%\extensions\python\bin;%TUSCANY_SDOCPP%\bin;%AXIS2C_HOME%\lib;%PATH%
 set PYTHONPATH=%TUSCANY_SCACPP%\extensions\python\bin
 
-cd %TUSCANY_SCACPP_SYSTEM_ROOT%\packages\sample.calculator.client
+cd %TUSCANY_SCACPP_SYSTEM_ROOT%\sample.calculator.client
 python calculator_client.py div 5 2
     
 :end

Modified: incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/runclient.sh
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/runclient.sh?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/runclient.sh (original)
+++ incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.client/runclient.sh Thu Oct  5 22:07:31 2006
@@ -45,5 +45,5 @@
 export TUSCANY_SCACPP_SYSTEM_ROOT=$TEST_SYSTEM
 export TUSCANY_SCACPP_DEFAULT_COMPONENT=sample.calculator.CalculatorComponent
 
-cd $TUSCANY_SCACPP_SYSTEM_ROOT/packages/sample.calculator.client
+cd $TUSCANY_SCACPP_SYSTEM_ROOT/sample.calculator.client
 python calculator_client.py div 5 2

Added: incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.solution.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.solution.composite?view=auto&rev=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.solution.composite (added)
+++ incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.solution.composite Thu Oct  5 22:07:31 2006
@@ -0,0 +1,32 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--
+   Licensed to the Apache Software Foundation (ASF) under one
+   or more contributor license agreements.  See the NOTICE file
+   distributed with this work for additional information
+   regarding copyright ownership.  The ASF licenses this file
+   to you under the Apache License, Version 2.0 (the
+   "License"); you may not use this file except in compliance
+   with the License.  You may obtain a copy of the License at
+   
+     http://www.apache.org/licenses/LICENSE-2.0
+     
+   Unless required by applicable law or agreed to in writing,
+   software distributed under the License is distributed on an
+   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+   KIND, either express or implied.  See the License for the
+   specific language governing permissions and limitations
+   under the License.
+-->
+
+<composite xmlns="http://www.osoa.org/xmlns/sca/1.0"
+	name="sample.calculator.solution">
+	
+        <component name="sample.calculator.CalculatorComponent">
+        	<implementation.composite name="sample.calculator" />
+       	</component>
+
+        <component name="sample.calculator.CalculatorWSClientComponent">
+        	<implementation.composite name="sample.calculator.wsclient" />
+       	</component>
+
+</composite>

Propchange: incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.solution.composite
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.solution.composite
------------------------------------------------------------------------------
    svn:keywords = Rev Date

Modified: incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/Makefile.am?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/Makefile.am Thu Oct  5 22:07:31 2006
@@ -1,5 +1,5 @@
 deploydir=$(prefix)/samples/PythonCalculator/deploy
-wsclientdir=$(deploydir)/packages/sample.calculator.wsclient
+wsclientdir=$(deploydir)/sample.calculator.wsclient
 prgbindir=$(deploydir)/bin
 
 wsclient_DATA = *.py *.wsdl *.composite

Modified: incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/runwsclient.bat
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/runwsclient.bat?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/runwsclient.bat (original)
+++ incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/runwsclient.bat Thu Oct  5 22:07:31 2006
@@ -43,7 +43,7 @@
 set PATH=%TUSCANY_SCACPP%\bin;%TUSCANY_SCACPP%\extensions\python\bin;%TUSCANY_SDOCPP%\bin;%AXIS2C_HOME%\lib;%PATH%
 set PYTHONPATH=%TUSCANY_SCACPP%\extensions\python\bin
 
-cd %TUSCANY_SCACPP_SYSTEM_ROOT%\packages\sample.calculator.wsclient
+cd %TUSCANY_SCACPP_SYSTEM_ROOT%\sample.calculator.wsclient
 python calculator_wsclient.py div 5 2
     
 :end

Modified: incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/runwsclient.sh
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/runwsclient.sh?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/runwsclient.sh (original)
+++ incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator.wsclient/runwsclient.sh Thu Oct  5 22:07:31 2006
@@ -45,5 +45,5 @@
 export TUSCANY_SCACPP_SYSTEM_ROOT=$TEST_SYSTEM
 export TUSCANY_SCACPP_DEFAULT_COMPONENT=sample.calculator.CalculatorWSClientComponent
 
-cd $TUSCANY_SCACPP_SYSTEM_ROOT/packages/sample.calculator.wsclient
+cd $TUSCANY_SCACPP_SYSTEM_ROOT/sample.calculator.wsclient
 python calculator_wsclient.py div 5 2

Modified: incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator/Makefile.am?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/PythonCalculator/sample.calculator/Makefile.am Thu Oct  5 22:07:31 2006
@@ -1,5 +1,5 @@
 deploydir=$(prefix)/samples/PythonCalculator/deploy
-compositedir=$(deploydir)/packages/sample.calculator
+compositedir=$(deploydir)/sample.calculator
 prgbindir=$(deploydir)/bin
 
 composite_DATA = *.composite *.componentType *.wsdl *.py

Modified: incubator/tuscany/cpp/sca/samples/RubyBank/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/RubyBank/Makefile.am?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/RubyBank/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/RubyBank/Makefile.am Thu Oct  5 22:07:31 2006
@@ -1,4 +1,4 @@
-deploydir=$(prefix)/samples/RubyBank/deploy/configuration/bigbank.accountmanagement
+deploydir=$(prefix)/samples/RubyBank/deploy
 SUBDIRS = bigbank.account bigbank.client
-EXTRA_DIST = bigbank.accountmanagement README.html
-deploy_DATA = bigbank.accountmanagement/bigbank.accountmanagement.composite
+EXTRA_DIST = *.composite README.html
+deploy_DATA = *.composite

Modified: incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.account/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.account/Makefile.am?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.account/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.account/Makefile.am Thu Oct  5 22:07:31 2006
@@ -1,5 +1,5 @@
 deploydir=$(prefix)/samples/RubyBank/deploy
-compositedir=$(deploydir)/packages/bigbank.account
+compositedir=$(deploydir)/bigbank.account
 prgbindir=$(deploydir)/bin
 
 prgbin_SCRIPTS = runwsserver.sh

Added: incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.accountmanagement.composite
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.accountmanagement.composite?view=auto&rev=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.accountmanagement.composite (added)
+++ incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.accountmanagement.composite Thu Oct  5 22:07:31 2006
@@ -0,0 +1,29 @@
+<?xml version="1.0" encoding="UTF-8"?>
+<!--
+   Licensed to the Apache Software Foundation (ASF) under one
+   or more contributor license agreements.  See the NOTICE file
+   distributed with this work for additional information
+   regarding copyright ownership.  The ASF licenses this file
+   to you under the Apache License, Version 2.0 (the
+   "License"); you may not use this file except in compliance
+   with the License.  You may obtain a copy of the License at
+   
+     http://www.apache.org/licenses/LICENSE-2.0
+     
+   Unless required by applicable law or agreed to in writing,
+   software distributed under the License is distributed on an
+   "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
+   KIND, either express or implied.  See the License for the
+   specific language governing permissions and limitations
+   under the License.
+-->
+
+<composite xmlns="http://www.osoa.org/xmlns/sca/1.0"
+	name="bigbank.accountmanagement">
+	
+	<component name="bigbank.AccountManagementComponent">
+		<implementation.composite name="bigbank.account"/>
+	</component>
+
+</composite>
+	
\ No newline at end of file

Propchange: incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.accountmanagement.composite
------------------------------------------------------------------------------
    svn:eol-style = native

Propchange: incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.accountmanagement.composite
------------------------------------------------------------------------------
    svn:keywords = Rev Date

Modified: incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/Makefile.am?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/Makefile.am Thu Oct  5 22:07:31 2006
@@ -1,5 +1,5 @@
 deploydir=$(prefix)/samples/RubyBank/deploy
-clientdir=$(deploydir)/packages/bigbank.client
+clientdir=$(deploydir)/bigbank.client
 prgbindir=$(deploydir)/bin
 
 client_DATA = *.rb

Modified: incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/runclient.bat
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/runclient.bat?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/runclient.bat (original)
+++ incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/runclient.bat Thu Oct  5 22:07:31 2006
@@ -44,7 +44,7 @@
 rem Run the client
 set PATH=%TUSCANY_SCACPP%\bin;%TUSCANY_SDOCPP%\bin;%AXIS2C_HOME%\lib;%PATH%
 
-cd %TUSCANY_SCACPP_SYSTEM_ROOT%\packages\bigbank.client
+cd %TUSCANY_SCACPP_SYSTEM_ROOT%\bigbank.client
 ruby -I%TUSCANY_SCACPP%\extensions\ruby\lib AccountClient.rb
 
 :end

Modified: incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/runclient.sh
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/runclient.sh?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/runclient.sh (original)
+++ incubator/tuscany/cpp/sca/samples/RubyBank/bigbank.client/runclient.sh Thu Oct  5 22:07:31 2006
@@ -45,5 +45,5 @@
 export TUSCANY_SCACPP_SYSTEM_ROOT=$TEST_SYSTEM
 export TUSCANY_SCACPP_DEFAULT_COMPONENT=bigbank.AccountManagementComponent
 
-cd $TUSCANY_SCACPP_SYSTEM_ROOT/packages/bigbank.client
+cd $TUSCANY_SCACPP_SYSTEM_ROOT/bigbank.client
 ruby -I$TUSCANY_SCACPP/extensions/ruby/lib AccountClient.rb

Modified: incubator/tuscany/cpp/sca/samples/RubyBank/deploy.cmd
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/RubyBank/deploy.cmd?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/RubyBank/deploy.cmd (original)
+++ incubator/tuscany/cpp/sca/samples/RubyBank/deploy.cmd Thu Oct  5 22:07:31 2006
@@ -29,21 +29,18 @@
 )
 
 if not exist %destinationPath%                          mkdir %destinationPath%
-if not exist %destinationPath%\packages                 mkdir %destinationPath%\packages
-if not exist %destinationPath%\packages\bigbank.account mkdir %destinationPath%\packages\bigbank.account
-if not exist %destinationPath%\packages\bigbank.client  mkdir %destinationPath%\packages\bigbank.client
-if not exist %destinationPath%\configuration            mkdir %destinationPath%\configuration
-if not exist %destinationPath%\configuration\bigbank.accountmanagement mkdir %destinationPath%\configuration\bigbank.accountmanagement
+if not exist %destinationPath%\bigbank.account mkdir %destinationPath%\bigbank.account
+if not exist %destinationPath%\bigbank.client  mkdir %destinationPath%\bigbank.client
 if not exist %destinationPath%\bin                      mkdir %destinationPath%\bin
 
-copy %sourcePath%\bigbank.account\*.rb        %destinationPath%\packages\bigbank.account
-copy %sourcePath%\bigbank.account\*.composite %destinationPath%\packages\bigbank.account
-copy %sourcePath%\bigbank.account\*.wsdl      %destinationPath%\packages\bigbank.account
-copy %sourcePath%\bigbank.account\*.xsd       %destinationPath%\packages\bigbank.account
+copy %sourcePath%\bigbank.account\*.rb        %destinationPath%\bigbank.account
+copy %sourcePath%\bigbank.account\*.composite %destinationPath%\bigbank.account
+copy %sourcePath%\bigbank.account\*.wsdl      %destinationPath%\bigbank.account
+copy %sourcePath%\bigbank.account\*.xsd       %destinationPath%\bigbank.account
 
-copy %sourcePath%\bigbank.client\*.rb         %destinationPath%\packages\bigbank.client
+copy %sourcePath%\bigbank.client\*.rb         %destinationPath%\bigbank.client
 
-copy %sourcePath%\bigbank.accountmanagement\*.composite   %destinationPath%\configuration\bigbank.accountmanagement
+copy %sourcePath%\*.composite   %destinationPath%
 
 copy %sourcePath%\bigbank.account\*.bat       %destinationPath%\bin
 copy %sourcePath%\bigbank.client\*.bat        %destinationPath%\bin

Modified: incubator/tuscany/cpp/sca/samples/RubyCalculator/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/RubyCalculator/Makefile.am?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/RubyCalculator/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/RubyCalculator/Makefile.am Thu Oct  5 22:07:31 2006
@@ -1,4 +1,4 @@
-deploydir=$(prefix)/samples/RubyCalculator/deploy/configuration
+deploydir=$(prefix)/samples/RubyCalculator/deploy
 SUBDIRS = sample.calculator sample.calculator.client sample.calculator.wsclient
-EXTRA_DIST = sample.calculator.solution README.html
-deploy_DATA = sample.calculator.solution/sample.calculator.solution.composite
\ No newline at end of file
+EXTRA_DIST = *.composite README.html
+deploy_DATA = *.composite

Modified: incubator/tuscany/cpp/sca/samples/RubyCalculator/deploy.cmd
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/RubyCalculator/deploy.cmd?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/RubyCalculator/deploy.cmd (original)
+++ incubator/tuscany/cpp/sca/samples/RubyCalculator/deploy.cmd Thu Oct  5 22:07:31 2006
@@ -28,23 +28,21 @@
 set destinationPath=%2
 )
 
-if not exist %destinationPath%\packages                   mkdir %destinationPath%\packages 
-if not exist %destinationPath%\packages\sample.calculator mkdir %destinationPath%\packages\sample.calculator
-copy %sourcePath%\sample.calculator\*.composite     %destinationPath%\packages\sample.calculator
-copy %sourcePath%\sample.calculator\*.rb            %destinationPath%\packages\sample.calculator
-copy %sourcePath%\sample.calculator\Calculator.wsdl %destinationPath%\packages\sample.calculator
+if not exist %destinationPath%                   mkdir %destinationPath%
+if not exist %destinationPath%\sample.calculator mkdir %destinationPath%\sample.calculator
+copy %sourcePath%\sample.calculator\*.composite     %destinationPath%\sample.calculator
+copy %sourcePath%\sample.calculator\*.rb            %destinationPath%\sample.calculator
+copy %sourcePath%\sample.calculator\Calculator.wsdl %destinationPath%\sample.calculator
 
-if not exist %destinationPath%\packages\sample.calculator.client mkdir %destinationPath%\packages\sample.calculator.client
-copy %sourcePath%\sample.calculator.client\CalculatorClient.rb %destinationPath%\packages\sample.calculator.client
+if not exist %destinationPath%\sample.calculator.client mkdir %destinationPath%\sample.calculator.client
+copy %sourcePath%\sample.calculator.client\CalculatorClient.rb %destinationPath%\sample.calculator.client
 
-if not exist %destinationPath%\packages\sample.calculator.wsclient mkdir %destinationPath%\packages\sample.calculator.wsclient
-copy %sourcePath%\sample.calculator.wsclient\CalculatorWSClient.rb               %destinationPath%\packages\sample.calculator.wsclient
-copy %sourcePath%\sample.calculator.wsclient\sample.calculator.wsclient.composite %destinationPath%\packages\sample.calculator.wsclient
-copy %sourcePath%\sample.calculator.wsclient\Calculator.wsdl                      %destinationPath%\packages\sample.calculator.wsclient
+if not exist %destinationPath%\sample.calculator.wsclient mkdir %destinationPath%\sample.calculator.wsclient
+copy %sourcePath%\sample.calculator.wsclient\CalculatorWSClient.rb               %destinationPath%\sample.calculator.wsclient
+copy %sourcePath%\sample.calculator.wsclient\sample.calculator.wsclient.composite %destinationPath%\sample.calculator.wsclient
+copy %sourcePath%\sample.calculator.wsclient\Calculator.wsdl                      %destinationPath%\sample.calculator.wsclient
 
-if not exist %destinationPath%\configuration                            mkdir %destinationPath%\configuration
-if not exist %destinationPath%\configuration\sample.calculator.solution mkdir %destinationPath%\configuration\sample.calculator.solution
-copy %sourcePath%\sample.calculator.solution\*.composite %destinationPath%\configuration\sample.calculator.solution
+copy %sourcePath%\*.composite %destinationPath%
 
 if not exist %destinationPath%\bin mkdir %destinationPath%\bin
 copy %sourcePath%\sample.calculator.client\runclient.bat     %destinationPath%\bin

Modified: incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/Makefile.am
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/Makefile.am?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/Makefile.am (original)
+++ incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/Makefile.am Thu Oct  5 22:07:31 2006
@@ -1,5 +1,5 @@
 deploydir=$(prefix)/samples/RubyCalculator/deploy
-clientdir=$(deploydir)/packages/sample.calculator.client
+clientdir=$(deploydir)/sample.calculator.client
 prgbindir=$(deploydir)/bin
 
 client_DATA = *.rb

Modified: incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/runclient.bat
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/runclient.bat?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/runclient.bat (original)
+++ incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/runclient.bat Thu Oct  5 22:07:31 2006
@@ -42,7 +42,7 @@
 
 set PATH=%TUSCANY_SCACPP%\bin;%TUSCANY_SDOCPP%\bin;%AXIS2C_HOME%\lib;%PATH%
 
-cd %TUSCANY_SCACPP_SYSTEM_ROOT%\packages\sample.calculator.client
+cd %TUSCANY_SCACPP_SYSTEM_ROOT%\sample.calculator.client
 ruby -I%TUSCANY_SCACPP%\extensions\ruby\lib CalculatorClient.rb
 
 :end

Modified: incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/runclient.sh
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/runclient.sh?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================
--- incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/runclient.sh (original)
+++ incubator/tuscany/cpp/sca/samples/RubyCalculator/sample.calculator.client/runclient.sh Thu Oct  5 22:07:31 2006
@@ -45,5 +45,5 @@
 export TUSCANY_SCACPP_SYSTEM_ROOT=$TEST_SYSTEM
 export TUSCANY_SCACPP_DEFAULT_COMPONENT=sample.calculator.CalculatorComponent
 
-cd $TUSCANY_SCACPP_SYSTEM_ROOT/packages/sample.calculator.client
+cd $TUSCANY_SCACPP_SYSTEM_ROOT/sample.calculator.client
 ruby -I$TUSCANY_SCACPP/extensions/ruby/lib CalculatorClient.rb



---------------------------------------------------------------------
To unsubscribe, e-mail: tuscany-commits-unsubscribe@ws.apache.org
For additional commands, e-mail: tuscany-commits-help@ws.apache.org
--- incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/SCARuntime.cpp (original)
+++ incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/SCARuntime.cpp Thu Oct  5 22:07:31 2006
@@ -42,13 +42,17 @@
         static const char* TUSCANY_SCACPP = "TUSCANY_SCACPP";
         static const char* TUSCANY_SCACPP_SYSTEM_ROOT = "TUSCANY_SCACPP_SYSTEM_ROOT";
         static const char* TUSCANY_SCACPP_DEFAULT_COMPONENT = "TUSCANY_SCACPP_DEFAULT_COMPONENT";
-            
+        
+        static const char* TUSCANY_SCACPP_ROOT = "TUSCANY_SCACPP_ROOT";
+        static const char* TUSCANY_SCACPP_COMPONENT = "TUSCANY_SCACPP_COMPONENT";
+        static const char* TUSCANY_SCACPP_PATH = "TUSCANY_SCACPP_PATH";
  
         // ==========================================================
         // Initialize static class member to not pointing at anything
         // ==========================================================
         SCARuntime* SCARuntime::instance = 0;
         string SCARuntime::systemRoot = "";
+        string SCARuntime::systemPath = "";
         string SCARuntime::defaultComponentName = "";
         
 
@@ -57,13 +61,24 @@
         // ==========================================================
         void SCARuntime::setSystemRoot(const string& root)
         {
-            LOGENTRY(1, "SCARuntime::");
+            LOGENTRY(1, "SCARuntime::setSystemRoot");
             systemRoot = root;
             LOGINFO_1(3, "SCARuntime::setSystemRoot - set to %s", root.c_str());
             LOGEXIT(1, "SCARuntime::setSystemRoot");
         }
 
         // ==========================================================
+        // Set the system configuration root
+        // ==========================================================
+        void SCARuntime::setSystemPath(const string& path)
+        {
+            LOGENTRY(1, "SCARuntime::setSystemPath");
+            systemPath = path;
+            LOGINFO_1(3, "SCARuntime::setSystemPath - set to %s", path.c_str());
+            LOGEXIT(1, "SCARuntime::setSystemPath");
+        }
+
+        // ==========================================================
         // Set the default component name
         // ==========================================================
         void SCARuntime::setDefaultComponentName(const string& componentName)
@@ -131,19 +146,39 @@
 
                 if (systemRoot == "")
                 {
-                    
-                    // Load the runtime
-                    // Get root from environment variable TUSCANY_SCACPP_SYSTEM_ROOT
-                    char* systemRootEnv = getenv(TUSCANY_SCACPP_SYSTEM_ROOT);
+                    // Get root from environment variable TUSCANY_SCACPP_ROOT
+                    char* systemRootEnv = getenv(TUSCANY_SCACPP_ROOT);
                     if (systemRootEnv == 0)
                     {
-                        string msg = TUSCANY_SCACPP_SYSTEM_ROOT;
+                        // Get root from environment variable TUSCANY_SCACPP_SYSTEM_ROOT
+                        systemRootEnv = getenv(TUSCANY_SCACPP_SYSTEM_ROOT);
+                    }
+                    if (systemRootEnv == 0)
+                    {
+                        string msg = TUSCANY_SCACPP_ROOT;
                         msg += " environment variable not set";
                         throw SystemConfigurationException(msg.c_str());
                     } 
 
                     systemRoot = systemRootEnv;
                 }
+                if (systemPath == "")
+                {
+                    
+                    // Get system path from environment variable TUSCANY_SCACPP_PATH
+                    char* systemPathEnv = getenv(TUSCANY_SCACPP_PATH);
+                    if (systemPathEnv == 0)
+                    {
+                    // Make the path optional for now
+//                        string msg = TUSCANY_SCACPP_PATH;
+//                        msg += " environment variable not set";
+//                        throw SystemConfigurationException(msg.c_str());
+                    }
+                    else
+                    {
+                        systemPath = systemPathEnv;
+                    }
+                }
             }
             
             LOGEXIT(1, "SCARuntime::getInstance");
@@ -165,6 +200,7 @@
                 delete instance;
                 instance = 0;
                 systemRoot = "";
+                systemPath = "";
                 defaultComponentName = "";        
             }
             
@@ -179,10 +215,11 @@
             LOGENTRY(1, "SCARuntime::load");
             
             LOGINFO_1(2,"configuration root: %s", systemRoot.c_str());
+            LOGINFO_1(2,"configuration path: %s", systemPath.c_str());
             
+            // Load the system composite
             ModelLoader loader(system);
-            // Load details of the composite
-            loader.load(systemRoot);
+            loader.load(systemRoot, systemPath);
             
             LOGEXIT(1, "SCARuntime::load");
         }
@@ -418,24 +455,28 @@
             if (!defaultComponent)
             {
                 // -------------------------------------------
-                // Get the default composite from the environment
+                // Get the default component name from the environment
                 // -------------------------------------------
                 if (defaultComponentName == "")
                 {
-                    const char* defMod = getenv(TUSCANY_SCACPP_DEFAULT_COMPONENT);
-                    if (!defMod)
+                    const char* defComp = getenv(TUSCANY_SCACPP_COMPONENT);
+                    if (!defComp)
+                    {
+                        defComp = getenv(TUSCANY_SCACPP_DEFAULT_COMPONENT);
+                    }
+                    if (!defComp)
                     {
-                        string message = TUSCANY_SCACPP_DEFAULT_COMPONENT;
+                        string message = TUSCANY_SCACPP_COMPONENT;
                         message += " environment variable not set";
                         throw SystemConfigurationException(message.c_str());
                     }
-                    defaultComponentName = defMod;
+                    defaultComponentName = defComp;
                 }
                 
                 defaultComponent = getSystem()->findComponent(defaultComponentName);
                 if (!defaultComponent)
                 {
-                    string message = "Default component \'" + defaultComponentName + "\' not found";
+                    string message = "Component \'" + defaultComponentName + "\' not found";
                     throw SystemConfigurationException(message.c_str());
                 }
             }

Modified: incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/SCARuntime.h
URL: http://svn.apache.org/viewvc/incubator/tuscany/cpp/sca/runtime/core/src/tuscany/sca/core/SCARuntime.h?view=diff&rev=453499&r1=453498&r2=453499
==============================================================================